summaryrefslogtreecommitdiff
path: root/sw/source/core/edit/ednumber.cxx
diff options
context:
space:
mode:
authorCédric Bosdonnat <cedricbosdo@openoffice.org>2010-11-25 17:08:45 +0100
committerCédric Bosdonnat <cedricbosdo@openoffice.org>2010-11-25 17:12:34 +0100
commitc16ba8a04fd4599e439e7e039705e41691c43acb (patch)
tree66a1c67973a674245548e10ff0746d1e473a7703 /sw/source/core/edit/ednumber.cxx
parente9eaf033646695987e218907a565b555b976c5c8 (diff)
Removed DBG_UTIL from sw
* Fixed the different dbglevel builds * This needed to change all the sw local ASSERT to OSL_ENSURE...
Diffstat (limited to 'sw/source/core/edit/ednumber.cxx')
-rw-r--r--sw/source/core/edit/ednumber.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/sw/source/core/edit/ednumber.cxx b/sw/source/core/edit/ednumber.cxx
index 6ae13009ba74..ccbbb44ddd4f 100644
--- a/sw/source/core/edit/ednumber.cxx
+++ b/sw/source/core/edit/ednumber.cxx
@@ -564,8 +564,8 @@ BOOL SwEditShell::IsProtectedOutlinePara() const
// GetTxtColl()->GetOutlineLevel() );
// int nTmpLvl = pTmpNd->GetTxtNode()->GetOutlineLevel();//#outline level,zhaojianwei
int nTmpLvl = pTmpNd->GetTxtNode()->GetAttrOutlineLevel();
- // ASSERT( nTmpLvl >= 0 && nTmpLvl < MAXLEVEL,
- ASSERT( nTmpLvl >= 0 && nTmpLvl <= MAXLEVEL, //<-end,zhaojianwei
+ // OSL_ENSURE( nTmpLvl >= 0 && nTmpLvl < MAXLEVEL,
+ OSL_ENSURE( nTmpLvl >= 0 && nTmpLvl <= MAXLEVEL, //<-end,zhaojianwei
"<SwEditShell::IsProtectedOutlinePara()>" );
// <--
if( bFirst )
@@ -583,10 +583,10 @@ BOOL SwEditShell::IsProtectedOutlinePara() const
}
}
}
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
else
{
- ASSERT(!this, "Cursor not on an outline node" );
+ OSL_ENSURE(!this, "Cursor not on an outline node" );
}
#endif
return bRet;
@@ -665,7 +665,7 @@ BYTE SwEditShell::GetNumLevel() const
const SwTxtNode* pTxtNd = pCrsr->GetNode()->GetTxtNode();
// --> FME 2005-09-12 #124972# Made code robust:
- ASSERT( pTxtNd, "GetNumLevel() without text node" )
+ OSL_ENSURE( pTxtNd, "GetNumLevel() without text node" );
if ( !pTxtNd )
return nLevel;
// <--